SystemOrganization addCategory: #ConfigurationOfMerlin!

Object subclass: #ConfigurationOfMerlin
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfMerlin'!

!ConfigurationOfMerlin commentStamp: '<historical>' prior: 0!
(ConfigurationOfMerlin project version: #stable) load!

!ConfigurationOfMerlin classSide methodsFor: 'private' stamp: 'AlexandreBergel 12/28/2010 13:53'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfMerlin classSide methodsFor: 'private' stamp: 'AlexandreBergel 12/28/2010 13:53'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfMerlin classSide methodsFor: 'metacello tool support' stamp: 'AlexandreBergel 12/28/2010 13:53'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfMerlin classSide methodsFor: 'metacello tool support' stamp: 'AlexandreBergel 12/28/2010 13:53'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfMerlin classSide methodsFor: 'loading' stamp: 'AlexandreBergel 12/28/2010 13:53'!
load
	"self load"

	^self project stableVersion load! !

!ConfigurationOfMerlin classSide methodsFor: 'metacello tool support' stamp: 'AlexandreBergel 12/28/2010 13:53'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfMerlin classSide methodsFor: 'accessing' stamp: 'AlexandreBergel 12/28/2010 13:53'!
project

	^self new project! !

!ConfigurationOfMerlin classSide methodsFor: 'unloading Metacello' stamp: 'AlexandreBergel 12/28/2010 13:53'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfMerlin methodsFor: 'baselines' stamp: 'AlexandreBergel 12/28/2010 13:53'!
baseline10: spec 
        <version: '1.0-baseline'>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec repository: 'http://www.squeaksource.com/Merlin'.    
                "spec 
                        package: 'Example-Core';
                        package: 'Example-Tests' with: [ spec requires: 'Example-Core' ]"
			spec package: 'Merlin'.
                ].! !

!ConfigurationOfMerlin methodsFor: 'baselines' stamp: 'StephaneDucasse 2/10/2013 21:41'!
default: spec 
        <version: 'default'>
        self halt: 'Normally you should not invoke this method since moose relies on the dev version'.

        spec for: #common do: [
                spec blessing: #baseline.
                spec repository: 'http://www.squeaksource.com/Merlin'.    
                "spec 
                        package: 'Example-Core';
                        package: 'Example-Tests' with: [ spec requires: 'Example-Core' ]"
			spec package: 'Merlin'.
			spec 
				group: 'Core' with: #('Merlin');
				group: 'Tests' with: #('Merlin').
                ].! !

!ConfigurationOfMerlin methodsFor: 'symbolic versions' stamp: 'StephaneDucasse 2/10/2013 21:40'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.8'.
! !

!ConfigurationOfMerlin methodsFor: 'accessing' stamp: 'AlexandreBergel 12/28/2010 13:53'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfMerlin methodsFor: 'symbolic versions' stamp: 'StephaneDucasse 2/10/2013 21:40'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '1.8'.
! !

!ConfigurationOfMerlin methodsFor: 'versions' stamp: 'AlexandreBergel 3/25/2011 21:58'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- updating the configuration'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/25/2011 21:58'.
		spec package: 'Merlin' with: 'Merlin-cyrilledelaunay.100'. ].
! !

!ConfigurationOfMerlin methodsFor: 'versions' stamp: 'AlexandreBergel 3/25/2011 22:03'!
version11: spec
	<version: '1.1' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/25/2011 22:03'.
		spec package: 'Merlin' with: 'Merlin-cyrilledelaunay.100'. ].
! !

!ConfigurationOfMerlin methodsFor: 'versions' stamp: 'AlexandreBergel 5/26/2011 18:30'!
version12: spec
	<version: '1.2' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'back to merlin-119
1.2 : improvement, multiple selection in a list works much better'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/26/2011 18:30'.
		spec package: 'Merlin' with: 'Merlin-cyrilledelaunay.120'. ].
! !

!ConfigurationOfMerlin methodsFor: 'versions' stamp: 'AlexandreBergel 9/28/2011 17:18'!
version13: spec
	<version: '1.3' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'added several small improvments
1.3 : Integrating Benjamin fix'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/28/2011 17:18'.
		spec package: 'Merlin' with: 'Merlin-BenjaminVanRyseghem.136'. ].
! !

!ConfigurationOfMerlin methodsFor: 'versions' stamp: 'AlexandreBergel 9/30/2011 09:52'!
version14: spec
	<version: '1.4' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.3 : Integrating Benjamin fix
1.4 : Replaced PluggableListMorphOfMany by PluggableListMorph'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/30/2011 09:52'.
		spec package: 'Merlin' with: 'Merlin-AlexandreBergel.137'. ].
! !

!ConfigurationOfMerlin methodsFor: 'versions' stamp: 'AlexandreBergel 9/30/2011 09:52'!
version15: spec
	<version: '1.5' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.4 : Replaced PluggableListMorphOfMany by PluggableListMorph'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/30/2011 09:52'.
		spec package: 'Merlin' with: 'Merlin-AlexandreBergel.137'. ].
! !

!ConfigurationOfMerlin methodsFor: 'versions' stamp: 'AlexandreBergel 11/21/2012 08:41'!
version16: spec
	<version: '1.6' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.6 : fixed the quote in dropPart, add a better description for the select: [:each | inputfield]
1.6 : Removed dependency from BlockContext. Merged with last version'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/21/2012 08:41'.
		spec package: 'Merlin' with: 'Merlin-AlexandreBergel.141'. ].
! !

!ConfigurationOfMerlin methodsFor: 'versions' stamp: 'AlexandreBergel 11/21/2012 08:42'!
version17: spec
	<version: '1.7' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.6 : Removed dependency from BlockContext. Merged with last version'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/21/2012 08:42'.
		spec package: 'Merlin' with: 'Merlin-AlexandreBergel.141'. ].
! !

!ConfigurationOfMerlin methodsFor: 'versions' stamp: 'StephaneDucasse 2/10/2013 21:39'!
version18: spec
	<version: '1.8' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'Removing references to PluggableButtonMorphPlus'.
		spec author: 'StephaneDucasse'.
		spec timestamp: '2/10/2013 09:42'.
		spec package: 'Merlin' with: 'Merlin-StephaneDucasse.142'. ].
! !
